%define major      2
%define libname    %mklibname %{name} %{major}
%define libnamedev %mklibname %{name} -d

Name:           pjproject
Version:        2.7.2
Release:        %mkrel 2
Summary:        Libraries for building embedded/non-embedded VoIP applications
Group:          System/Libraries
License:        GPLv2+
URL:            http://www.pjsip.org

Source0:        http://www.pjsip.org/release/%{version}/%{name}-%{version}.tar.bz2

# Tell the build system not to use most of the third_party directory
Patch1:         pjproject_no_third_party.patch
# Keep the .pc file clean
# see https://bugzilla.redhat.com/show_bug.cgi?id=728302#c66
Patch2:         pjproject_fixup_pc_file.patch
# Add a config_site.h file to increase performance and set reasonable server
# configuration for running as a server and not just a client
Patch3:         pjproject_config_site.patch
# Fix ARMv7 endianness
Patch4:         pjproject-armv7.patch
# Add aarch64 detection
Patch5:         pjproject-aarch64.patch
# Fix ppc64 detection
Patch6:         pjproject-ppc64.patch
# Don't use SSE2 if it is not available
Patch8:		pjproject-sse2.patch

Patch20:         gnutls.patch
Patch21:         add_dtls_transport.patch
Patch22:         pj_ice_sess.patch

Patch30:	pjproject-2.5.5-parallel.patch

Patch40:	rfc6062.patch

BuildRequires:  gsm-devel
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(libsrtp2)
BuildRequires:  pkgconfig(uuid)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(portaudio-2.0)
BuildRequires:  pkgconfig(python2)
BuildRequires:  pkgconfig(speex)
BuildRequires:  pkgconfig(speexdsp)


%description
This package provides the Open Source, comprehensive, high performance,
small footprint multimedia communication libraries written in C
language for building embedded/non-embedded VoIP applications.
It contains:
- PJSIP - Open Source SIP Stack
- PJMEDIA - Open Source Media Stack
- PJNATH - Open Source NAT Traversal Helper Library
- PJLIB-UTIL - Auxiliary Library
- PJLIB - Ultra Portable Base Framework Library
- PJSUA2 - Object Oriented abstractions layer for PJSUA


%package -n     %{libname}
Summary:        Libraries for building embedded/non-embedded VoIP applications
Group:          System/Libraries

%description -n %{libname}
This package provides the Open Source, comprehensive, high performance,
small footprint multimedia communication libraries written in C
language for building embedded/non-embedded VoIP applications.
It contains:
- PJSIP - Open Source SIP Stack
- PJMEDIA - Open Source Media Stack
- PJNATH - Open Source NAT Traversal Helper Library
- PJLIB-UTIL - Auxiliary Library
- PJLIB - Ultra Portable Base Framework Library
- PJSUA2 - Object Oriented abstractions layer for PJSUA

This package contains the shared library part of ccrtp.


%package -n     %{libnamedev}
Summary:        Development files to use pjproject
Group:          Development/Libraries
Provides:       %{name}-devel = %{version}-%{release}
Requires:       %{libname} = %{version}-%{release}

%description -n %{libnamedev}
Header information for:
- PJSIP - Open Source SIP Stack
- PJMEDIA - Open Source Media Stack
- PJNATH - Open Source NAT Traversal Helper Library
- PJLIB-UTIL - Auxiliary Library
- PJLIB - Ultra Portable Base Framework Library


%package -n     pjsua
Summary:        command line SIP user agent
Group:          System/Libraries

%description -n pjsua
pjsua is an open source command line SIP user agent (softphone)
that is used as the reference implementation for PJSIP, PJNATH, and PJMEDIA.
Despite its simple command line appearance, it does pack many features!


%package -n     python-pjsua
Summary:        PJSUA Python Module
Group:          Development/Python

%description -n python-pjsua
The PJSUA for Python Module is an object oriented Python
wrapper/abstraction/modules for PJSUA API.

%prep
%setup -q
%apply_patches

# make sure we don't bundle these third-party libraries
# (They're excluded through ./configure, but this is an
# additional safety net)
rm -rf third_party/BaseClasses
rm -rf third_party/bdsound
rm -rf third_party/bin
rm -rf third_party/g7221
rm -rf third_party/gsm
rm -rf third_party/milenage
rm -rf third_party/mp3
rm -rf third_party/portaudio
rm -rf third_party/resample
rm -rf third_party/speex
rm -rf third_party/srtp
rm -rf third_party/ilbc
rm -rf third_party/build/baseclasses
rm -rf third_party/build/g7221
rm -rf third_party/build/gsm
rm -rf third_party/build/milenage
rm -rf third_party/build/portaudio/src
rm -rf third_party/build/resample
rm -rf third_party/build/samplerate
rm -rf third_party/build/speex
rm -rf third_party/build/srtp
rm -rf third_party/build/ilbc

%build
# Regenerate aconfigure for Patch8
autoconf aconfigure.ac > aconfigure

# We're building without audio or video support, as Asterisk isn't using
# that functionality, and it made it easier to ensure that we don't
# bundle any unnecessary libraries.  Please contact me if your project
# needs this support, and I'll re-enable it
export CFLAGS="-DPJ_HAS_IPV6=1 -DNDEBUG ${ARCHFLAGS} %{optflags}"

%configure2_5x \
	--enable-shared        \
	--with-external-gsm    \
	--with-external-pa     \
	--with-external-speex  \
	--with-external-srtp   \
	--disable-opencore-amr \
	--disable-resample     \
	--disable-sound        \
	--disable-video        \
	--disable-v4l2         \
	--disable-ilbc-codec   \
	--disable-libyuv       \
	--disable-g7221-codec

%make_build dep
%make_build

pushd pjsip-apps/src/python
    %py2_build
popd

%install
rm -rf %buildroot
%make_install

pushd pjsip-apps/src/python
    %py2_install
popd

install -p -D -m 0755 pjsip-apps/bin/pjsua-* %{buildroot}%{_bindir}/pjsua

# Remove the static libraries, as they aren't wanted
find %{buildroot} -type f -name "*.a" -delete


%files -n %{libname}
%doc README.txt README-RTEMS INSTALL.txt
%{_libdir}/lib*.so.*

%files -n %{libnamedev}
%{_libdir}/lib*.so
%{_includedir}/pj++/
%{_includedir}/pj/
%{_includedir}/pjlib-util/
%{_includedir}/pjmedia-audiodev/
%{_includedir}/pjmedia-codec/
%{_includedir}/pjmedia-videodev/
%{_includedir}/pjmedia/
%{_includedir}/pjnath/
%{_includedir}/pjsip-simple/
%{_includedir}/pjsip-ua/
%{_includedir}/pjsip/
%{_includedir}/pjsua-lib/
%{_includedir}/pjsua2/
%{_includedir}/*.h
%{_includedir}/*.hpp
%{_libdir}/pkgconfig/libpjproject.pc

%files -n python-pjsua
%doc pjsip-apps/src/python/samples
%{python2_sitearch}/_pjsua.so
%{python2_sitearch}/pjsua-*.egg-info
%{python2_sitearch}/pjsua.py*

%files -n pjsua
%{_bindir}/pjsua


%changelog
* Fri Nov 20 2020 tex - 2.7.2-2pclos2020
- rebuild against updates

* Tue Jun 18 2019 tex - 2.7.2-1pclos2019
- new

* Sun Mar 19 2017 bb2 <bb2> 2.5.5-2pclos2016
- clean up BR

* Fri Mar 17 2017 pp <pp> 2.5.5-1pclos2017
- imported package

